==> apache-dubbo-3.0.4-src.zip: apache-dubbo-3.0.4-src/dubbo-remoting/dubbo-remoting-api/src/test/java/org/apache/dubbo/remoting/buffer/ChannelBufferFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.remoting.buffer;


import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.nio.ByteBuffer;
/**
 * {@link DirectChannelBufferFactory}
 * {@link HeapChannelBufferFactory}
 */
public class ChannelBufferFactoryTest {

    @Test
    public void test() {
        ChannelBufferFactory directChannelBufferFactory = DirectChannelBufferFactory.getInstance();
        ChannelBufferFactory heapChannelBufferFactory = HeapChannelBufferFactory.getInstance();

        ChannelBuffer directBuffer1 = directChannelBufferFactory.getBuffer(16);
        ChannelBuffer directBuffer2 = directChannelBufferFactory.getBuffer(ByteBuffer.allocate(16));
        ChannelBuffer directBuffer3 = directChannelBufferFactory.getBuffer(new byte[]{1}, 0, 1);
        Assertions.assertTrue(directBuffer1.isDirect());
        Assertions.assertTrue(directBuffer2.isDirect());
        Assertions.assertTrue(directBuffer3.isDirect());

        ChannelBuffer heapBuffer1 = heapChannelBufferFactory.getBuffer(16);
        ChannelBuffer heapBuffer2 = heapChannelBufferFactory.getBuffer(ByteBuffer.allocate(16));
        ChannelBuffer heapBuffer3 = heapChannelBufferFactory.getBuffer(new byte[]{1}, 0, 1);
        Assertions.assertTrue(heapBuffer1.hasArray());
        Assertions.assertTrue(heapBuffer2.hasArray());
        Assertions.assertTrue(heapBuffer3.hasArray());
    }

}

==> apache-dubbo-3.3.6-src.zip: apache-dubbo-3.3.6-src/dubbo-remoting/dubbo-remoting-api/src/test/java/org/apache/dubbo/remoting/buffer/ChannelBufferFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.remoting.buffer;

import java.nio.ByteBuffer;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 * {@link DirectChannelBufferFactory}
 * {@link HeapChannelBufferFactory}
 */
class ChannelBufferFactoryTest {

    @Test
    void test() {
        ChannelBufferFactory directChannelBufferFactory = DirectChannelBufferFactory.getInstance();
        ChannelBufferFactory heapChannelBufferFactory = HeapChannelBufferFactory.getInstance();

        ChannelBuffer directBuffer1 = directChannelBufferFactory.getBuffer(16);
        ChannelBuffer directBuffer2 = directChannelBufferFactory.getBuffer(ByteBuffer.allocate(16));
        ChannelBuffer directBuffer3 = directChannelBufferFactory.getBuffer(new byte[] {1}, 0, 1);
        Assertions.assertTrue(directBuffer1.isDirect());
        Assertions.assertTrue(directBuffer2.isDirect());
        Assertions.assertTrue(directBuffer3.isDirect());

        ChannelBuffer heapBuffer1 = heapChannelBufferFactory.getBuffer(16);
        ChannelBuffer heapBuffer2 = heapChannelBufferFactory.getBuffer(ByteBuffer.allocate(16));
        ChannelBuffer heapBuffer3 = heapChannelBufferFactory.getBuffer(new byte[] {1}, 0, 1);
        Assertions.assertTrue(heapBuffer1.hasArray());
        Assertions.assertTrue(heapBuffer2.hasArray());
        Assertions.assertTrue(heapBuffer3.hasArray());
    }
}
